@@ -1,17 +1,17 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; price-quotes.scm - manage sub-processes.
 ;;; Copyright 2001 Rob Browning <rlb@cs.utexas.edu>
-;;; 
-;;; This program is free software; you can redistribute it and/or    
-;;; modify it under the terms of the GNU General Public License as   
-;;; published by the Free Software Foundation; either version 2 of   
-;;; the License, or (at your option) any later version.              
-;;;                                                                  
-;;; This program is distributed in the hope that it will be useful,  
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of   
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    
-;;; GNU General Public License for more details.                     
-;;;                                                                  
+;;;
+;;; This program is free software; you can redistribute it and/or
+;;; modify it under the terms of the GNU General Public License as
+;;; published by the Free Software Foundation; either version 2 of
+;;; the License, or (at your option) any later version.
+;;;
+;;; This program is distributed in the hope that it will be useful,
+;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;;; GNU General Public License for more details.
+;;;
 ;;; You should have received a copy of the GNU General Public License
 ;;; along with this program; if not, contact:
 ;;;
@@ -35,7 +35,7 @@
 
 (define (item-list->hash! lst hash
 			  getkey getval
-			  hashref hashset 
+			  hashref hashset
 			  list-duplicates?)
   ;; Takes a list of the form (item item item item) and returns a hash
   ;; formed by traversing the list, and getting the key and val from
@@ -58,7 +58,7 @@
 	  (if existing-val
 	      (hashset hash key (cons val existing-val))
 	      (hashset hash key (list val))))))
-  
+
   (for-each handle-item lst)
   hash)
 
@@ -118,7 +118,7 @@
   ;;
   ;; (<fq-method> sym sym ...)
   ;;
-  ;; i.e. (yahoo "RHAT" "LNUX" "IBM")
+  ;; i.e. (alphavantage "RHAT" "LNUX" "IBM")
   ;;
   ;; for currencies, we have
   ;;
@@ -205,12 +205,12 @@
     ;; a list of the corresponding commodities.  Also perform a bit of
     ;; optimization, merging calls for symbols to the same
     ;; Finance::Quote method.
-    ;; 
+    ;;
     ;; Returns a list of the info needed for a set of calls to
     ;; gnc-fq-helper.  Each item will of the list will be of the
     ;; form:
     ;;
-    ;; (("yahoo" (commodity-1 currency-1 tz-1)
+    ;; (("alphavantage" (commodity-1 currency-1 tz-1)
     ;;           (commodity-2 currency-2 tz-2) ...)
     ;;  ("fidelity_direct" (commodity-3 currency-3 tz-3)
     ;;                     (commodity-4 currency-4 tz-4) ...)
@@ -222,8 +222,12 @@
 	     ct))
 	   (commodity-list #f)
 	   (currency-list (filter
-			   (lambda (a) (not (gnc-commodity-equiv (cadr a) (caddr a))))
-			   (call-with-values 
+			   (lambda (a)
+                             (and
+                              (not (gnc-commodity-equiv (cadr a) (caddr a)))
+                              (not (string=? "XXX" (gnc-commodity-get-mnemonic (cadr a))))
+                              ))
+			   (call-with-values
                                (lambda () (partition!
                                            (lambda (cmd)
                                              (not (string=? (car cmd) "currency")))
@@ -255,10 +259,10 @@
     ;; their fq-suitable symbol strings.  i.e. turn the former into
     ;; the latter:
     ;;
-    ;; ("yahoo" (commodity-1 currency-1 tz-1)
+    ;; ("alphavantage" (commodity-1 currency-1 tz-1)
     ;;          (commodity-2 currency-2 tz-2) ...)
-    ;; 
-    ;; ("yahoo" "IBM" "AMD" ...)
+    ;;
+    ;; ("alphavantage" "IBM" "AMD" ...)
     ;;
 
     (if (equal? (car fq-call-data) "currency")
@@ -412,7 +416,7 @@
                                                       commodity currency
                                                       gnc-time))
             (if (not (null? saved-price))
-                (if (> (gnc-price-get-source saved-price) PRICE-SOURCE-FQ)
+                (if (>= (gnc-price-get-source saved-price) PRICE-SOURCE-FQ)
                     (begin
                       (gnc-price-begin-edit saved-price)
                       (gnc-price-set-time saved-price gnc-time)
@@ -449,6 +453,13 @@
                #f)))
        prices)))
 
+  ;; Add the alphavantage api key to the environment. This value is taken from
+  ;; the Online Quotes preference tab
+  (let* ((alphavantage-api-key (gnc-prefs-get-string "general.finance-quote" "alphavantage-api-key")))
+        (gnc:debug (string-concatenate (list "ALPHAVANTAGE_API_KEY=" alphavantage-api-key)))
+        (if (not (string-null? alphavantage-api-key))
+            (setenv "ALPHAVANTAGE_API_KEY" alphavantage-api-key)))
+
   ;; FIXME: uses of gnc:warn in here need to be cleaned up.  Right
   ;; now, they'll result in funny formatting.
 
@@ -607,4 +618,4 @@ Run 'gnc-fq-update' as root to install them.") "\n")))
       (format #t "Found Finance::Quote version ~A" (car sources))
       (newline)
 	  (gnc:msg "Found Finance::Quote version " (car sources))
-	  (gnc-quote-source-set-fq-installed (cdr sources))))))
+	  (gnc-quote-source-set-fq-installed (car sources) (cdr sources))))))
